from setuptools import setup

setup(name='ftThanos',
version="0.0.53",
description="A client for 53 API",
author="Thanos 53",
author_email="thanos@53paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
